@@ -1,4 +1,4 @@
-use std::{cmp, collections::HashMap, convert::TryFrom, io};
+use std::{cmp, collections::HashMap, io};
 
 use md5::{Digest, Md5};
 use noodles_fasta as fasta;
@@ -160,7 +160,7 @@ impl Builder {
             let end = (slice_alignment_end - 1) as usize;
 
             let mut hasher = Md5::new();
-            hasher.update(&reference_sequence[start..=end]);
+            hasher.update(&reference_sequence.as_ref()[start..=end]);
             <[u8; 16]>::from(hasher.finalize())
         } else {
             [0; 16]
