@@ -4,17 +4,19 @@ use byteorder::{LittleEndian, ReadBytesExt};
 
 use crate::reader::num::read_itf8;
 
-use super::{rans_advance_step, rans_get_cumulative_freq, rans_get_symbol_from_freq, rans_renorm};
+use super::{rans_advance_step, rans_get_cumulative_freq, rans_renorm};
 
 pub fn decode<R>(reader: &mut R, output: &mut [u8]) -> io::Result<()>
 where
     R: Read,
 {
-    let mut freqs = vec![0; 256];
-    let mut cumulative_freqs = vec![0; 256];
+    let mut freqs = [0; 256];
+    let mut cumulative_freqs = [0; 256];
 
     read_frequencies_0(reader, &mut freqs, &mut cumulative_freqs)?;
 
+    let cumulative_freqs_symbols_table = build_cumulative_freqs_symbols_table_0(&cumulative_freqs);
+
     let mut state = [0; 4];
     reader.read_u32_into::<LittleEndian>(&mut state)?;
 
@@ -27,7 +29,7 @@ where
             }
 
             let f = rans_get_cumulative_freq(state[j]);
-            let s = rans_get_symbol_from_freq(&cumulative_freqs, f);
+            let s = cumulative_freqs_symbols_table[f as usize];
 
             output[i + j] = s;
 
@@ -84,3 +86,20 @@ where
 
     Ok(())
 }
+
+pub fn build_cumulative_freqs_symbols_table_0(cumulative_freqs: &[u32]) -> [u8; 4096] {
+    let mut table = [0; 4096];
+    let mut sym = 0;
+
+    for (freq, cumulative_freq) in table.iter_mut().enumerate() {
+        let freq = freq as u32;
+
+        while sym < 255 && freq >= cumulative_freqs[(sym + 1) as usize] {
+            sym += 1;
+        }
+
+        *cumulative_freq = sym;
+    }
+
+    table
+}
